Random Factories
================

.. toctree::

   reference_rand_conditional
   reference_rand_profile_discrete_grid_uniform
   reference_rand_profile_discrete_uniform
   reference_rand_profile_histogram_grid_uniform
   reference_rand_profile_histogram_uniform
   reference_rand_profile_noisy_discrete_grid_uniform
   reference_rand_profile_noisy_discrete_uniform
   reference_rand_profile_ordinal_grid_uniform
   reference_rand_profile_ordinal_uniform
   reference_rand_profile_twelve_grid_uniform
   reference_rand_profile_twelve_uniform
   reference_rand_simplex_grid_uniform
   reference_rand_simplex_uniform
   reference_rand_strategy_ordinal_uniform
   reference_rand_strategy_threshold_grid_uniform
   reference_rand_strategy_threshold_uniform
   reference_rand_strategy_twelve_uniform
   reference_rand_tau_vector_grid_uniform
   reference_rand_tau_vector_uniform
